Building the TraitsUI Docs
============================

Dependency:
Sphinx

Optional Dependency:
`Enthought-sphinx-theme<https://github.com/enthought/enthought-sphinx-theme>`_

The docs can be built by running

$ make clean
$ make html

from ``docs/``, which contains the ``Makefile``.
Refer to ``docs/Makefile`` and ``docs/source/conf.py`` for further 
information on building the docs.

NOTE : ``docs/source/conf.py`` calls ``_version.py`` which is autogenerated 
when the user installs/develops the library.
